@@ -9,13 +9,16 @@
 #define UCT_VERSION_H_
 
 #define UCT_VERNO_MAJOR            1
-#define UCT_VERNO_MINOR            11
-#define UCT_VERNO_STRING           "1.11.1"
-#define UCT_SCM_VERSION            "c58db6b"
-                                   
+#define UCT_VERNO_MINOR            13
+#define UCT_VERNO_PATCH            1
+#define UCT_VERNO_EXTRA            ""
+#define UCT_VERNO_STRING           "1.13.1"
+#define UCT_SCM_VERSION            "09f27c0"
+#define UCT_SCM_BRANCH             ""
+
 #define UCT_MINOR_BIT              (16UL)
 #define UCT_MAJOR_BIT              (24UL)
-#define UCT_API                    ((1L<<UCT_MAJOR_BIT)|(11L << UCT_MINOR_BIT))
+#define UCT_API                    ((1L<<UCT_MAJOR_BIT)|(13L << UCT_MINOR_BIT))
 
 #define UCT_VERSION(major, minor)  (((major)<<UCT_MAJOR_BIT)|((minor)<<UCT_MINOR_BIT))
 
